# 5. Find Synopsis
The `./metro` executable is composed of several inter-related sub commands. Please see `./metro -h` for all available options. The synopsis for the sub command `find` shows its parameters and their usage. Optional parameters are shown in square brackets.

```
$ ./metro find [-h] [--subset SUBSET] \
                   --input INPUT [INPUT ...] \
                   --transcripts TRANSCRIPTS \
                   --output OUTPUT 
```

This part of the documentation describes options and concepts for `./metro find` sub command in more detail. With minimal configuration, the `find` sub command enables you to start running metro pipeline. In its most basic form, `./metro find` only has _three required inputs_.

## 5.1 Required Arguments
Each of the following arguments are required. Failure to provide a required argument will result in a non-zero exit-code.

`--input INPUT [INPUT ...]`  
> **Input MAF-like file(s) to process.**  
> *type: file*  
> 
> One or more MAF-like files can be provided. From the command-line, each input file should seperated by a space. Globbing is also supported! This makes selecting input files easier. Input MAF-like input files should be in an excel-like, CSV, or TSV format. For each input file a new output file will be generated in the specified output directory. Each file will end with the following extension: `.metro.tsv`.
> 
> ***Example:*** 
> `--input data/*.xls*`
---  
  `--output OUTPUT`
> **Path to an output directory.**   
> *type: path*
>   
> This location is where the metro will create all of its output files, also known as the pipeline's working directory. If the provided output directory does not exist, it will be created automatically.
> 
> ***Example:*** 
> `--output /scratch/$USER/RNA_hg38`
---  
  `--transcripts TRANSCRIPTS`
> **Transcriptomic FASTA file.**   
> *type: file*
>   
> This reference file contains the sequence of each transcript in the reference genome. The file can be generated by running the build sub command, (i.e. /path/to/build/output/transcripts.fa). When creating this reference file, it is very important to use the same genomic FASTA and annotation file to call and annotate variants. Failure to use the correct reference file may result in multiple warnings and/or errors. 
> 
> ***Example:*** 
> ` --transcripts transcripts.fa`

## 5.2 Optional Arguments
Each of the following arguments are optional and do not need to be provided. 

`-h, --help`            
> **Display Help.**  
> *type: boolean*
> 
> Shows command's synopsis, help message, and an example command
> 
> ***Example:*** 
> `--help`
---  
  `--subset SUBSET`            
> **Subset resulting mutated amino acid sequences.**  
> *type: int*
> 
> If defined, this option will obtain the mutated amino acid sequence (AAS) +/- N amino acids of the mutation start site. By default, the first 30 upstream and downstream amino acids from the mutation site are recorded for non-frame shift mutations. Amino acids downstream of a frame shit mutation will be reported until the end of the amino acids sequence for the variants transcript or until the first reported terminating stop codon is found.
>
> ***Example:*** 
> `--subset 30`

## 5.3 Example
Find metro with the references files generated in the build example.

```bash 
# login and load interactive session, as described in Getting Started

### Github
module purge
module load python/3.8

## Docker
singularity shell --bind /data/$USER docker://nciccbr/ccbr_metro_v1.4 nciccbr/ccbr_metro_v1.4

## Command 
 ./metro find \
            --input /scratch/$USER/METRO/test_VAF20_Variant.csv \
            --output /scratch/$USER/METRO \
            --transcripts /scratch/$USER/METRO/refs/transcripts.fa \
            --subset 30
```